@@ -1,5 +1,3 @@
-# coding: utf-8
-from __future__ import unicode_literals
 import unittest
 from datetime import datetime
 
@@ -7,10 +5,6 @@ from normality import normalize, latinize_text, ascii_text
 from normality import stringify, slugify, guess_encoding, guess_file_encoding
 
 
-# these tests assume PyICU is installed
-import icu  # noqa
-
-
 class NormalityTest(unittest.TestCase):
 
     def test_empty(self):
